@@ -2,7 +2,7 @@ import cv2
 import numpy as np
 import copy
 
-class ImageDehazer():
+class image_dehazer():
     def __init__(self):
         self.airlightEstimation_windowSze = 15
         self.boundaryConstraint_windowSze = 3
